@@ -1,6 +1,8 @@
 from typing import Union
+
 from django.contrib.auth.models import User
-from ..tokens import UntrustedToken, Token
+
+from ..tokens import Token, UntrustedToken
 
 
 class BaseUserRepository:
@@ -9,5 +11,7 @@ class BaseUserRepository:
 
 
 class BasePublicKeyRepository:
-    def attempt_to_verify_token(self, user: User, untrusted_token: UntrustedToken) -> Union[Token, None]:  # pragma: no cover
+    def attempt_to_verify_token(
+        self, user: User, untrusted_token: UntrustedToken
+    ) -> Union[Token, None]:  # pragma: no cover
         raise NotImplementedError()
